Description Details Custom mlr3 defaults Dictionary Super classes Methods References See Also Examples
A mlr3proba::LearnerSurv implementing flexible from package
flexsurv.
Calls flexsurv::flexsurvspline().
The distr prediction is estimated using the fitted custom distributions
from flexsurv::flexsurvspline() and the estimated coefficients however the prediction takes
place in this package and not in flexsurv for a much faster and more efficient
implementation.
As flexible spline models estimate the baseline hazard as the intercept, the linear predictor,
lp, can be calculated as in the classical setting. i.e. For fitted coefficients,
β = (β0,...,βP),
and covariates X^T = (X0,...,XP)^T, where X0 is a column
of 1s: lp = βX.
k:
Actual default: 0
Adjusted default: 1
Reason for change: The default value of 0 is equivalent to, and a much less efficient
implementation of, LearnerSurvParametric.
This Learner can be instantiated via the dictionary
mlr_learners or with the associated sugar function lrn():
1 2 | mlr_learners$get("surv.flexible")
lrn("surv.flexible")
|
mlr3::Learner -> mlr3proba::LearnerSurv -> LearnerSurvFlexible
new()Creates a new instance of this R6 class.
LearnerSurvFlexible$new()
clone()The objects of this class are cloneable with this method.
LearnerSurvFlexible$clone(deep = FALSE)
deepWhether to make a deep clone.
Royston P, Parmar MKB (2002). “Flexible parametric proportional-hazards and proportional-odds models for censored survival data, with application to prognostic modelling and estimation of treatment effects.” Statistics in Medicine, 21(15), 2175–2197. doi: 10.1002/sim.1203.
Dictionary of Learners: mlr3::mlr_learners
1 2 3 4 5 6 7 | if (requireNamespace("flexsurv")) {
learner = mlr3::lrn("surv.flexible")
print(learner)
# available parameters:
learner$param_set$ids()
}
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.